@@ -33,7 +33,7 @@ struct _Druid
 	GtkWidget *masq;
 	GtkWidget *ftp, *ssh, *telnet, *smtp, *dns, *finger, *www, *sslweb,
 		  *pop, *imap, *ident, *nntp, *ntp, *samba, *ipsec, *routed, *nfs,
-		  *x, *dhcp;
+		  *x, *dhcp, *upnp;
 
 	GtkWidget *icmp_echo, *icmp_traceroute, *icmp_tracert, *icmp_unreach,
 			*icmp_timestamp, *icmp_masking, *icmp_redir, *icmp_quench;
