@@ -188,25 +188,41 @@ stop_firewall (void)
 		else
 			sbin = g_strdup ("/sbin/ipchains");
 
-	if (NETFILTER) {
+	if (gnome_config_get_bool ("/firestarter/Druid/selectreject=TRUE")) {
+	if (NETFILTER)
 		command = g_strconcat (sbin, " -F;",
 				       sbin, " -X;",
 				       sbin, " -Z;",
-			     	       sbin, " -P INPUT ACCEPT;",
-				       sbin, " -P FORWARD ACCEPT;",
+			     	       sbin, " -P INPUT DROP;",
+				       sbin, " -P FORWARD DROP;",
 			               sbin, " -P OUTPUT ACCEPT;", NULL);
-		system (command);
-	}
-	else {
-		command = g_strconcat (sbin, " -X;",
-				       sbin, " -F;",
+	else
+		command = g_strconcat (sbin, " -F;",
+				       sbin, " -X;",
 				       sbin, " -Z;",
-				       sbin, " -P input ACCEPT;",
-				       sbin, " -P forward ACCEPT;",
-				       sbin, " -P output ACCEPT;", NULL);
-		system (command);
+			     	       sbin, " -P input REJECT;",
+				       sbin, " -P forward REJECT;",
+			               sbin, " -P output ACCEPT;", NULL);
 	}
 
+	if (gnome_config_get_bool ("/firestarter/Druid/selectdeny=TRUE")) {
+	if (NETFILTER)
+		command = g_strconcat (sbin, " -F;",
+				       sbin, " -X;",
+				       sbin, " -Z;",
+			     	       sbin, " -P INPUT DROP;",
+				       sbin, " -P FORWARD DROP;",
+			               sbin, " -P OUTPUT ACCEPT;", NULL);
+	else
+		command = g_strconcat (sbin, " -F;",
+				       sbin, " -X;",
+				       sbin, " -Z;",
+			     	       sbin, " -P input DENY;",
+				       sbin, " -P forward DENY;",
+			               sbin, " -P output ACCEPT;", NULL);
+	}
+
+	system (command);
 	g_free (sbin);
 	g_free (command);
 
