@@ -88,9 +88,10 @@ write_portfw_list (GtkWidget *clist)
 		}
 		/* Linux 2.4 case */
 		if (detect_netfilter ()) {
+		fprintf (f, "$IPT -A FORWARD -p %s -d %s --dport %s -j ACCEPT\n",
+			entry[3], entry[2], entry[1]);
 		fprintf (f, "$IPT -A PREROUTING -t nat -p %s -d $NET --dport %s -j DNAT --to %s:%s\n",
 			entry[3], entry[0], entry[2], entry[1]);
-
 		} else {
 		/* Linux 2.2 case */
 		fprintf (f, "$MSQADM portfw -a -P %s -L $IP %s -R %s %s\n",
